@@ -8,4 +8,7 @@ def mul(a, b):
     return a * b
 
 def div(a, b):
-    return a / b
\ No newline at end of file
+    return a / b
+
+def sqr(a):
+    return a * a
\ No newline at end of file
